@@ -1,5 +1,5 @@
 /*
-	SPDX-FileCopyrightText: 2009-2021 Graeme Gott <graeme@gottcode.org>
+	SPDX-FileCopyrightText: 2009-2022 Graeme Gott <graeme@gottcode.org>
 
 	SPDX-License-Identifier: GPL-3.0-or-later
 */
@@ -11,6 +11,8 @@
 #include <QApplication>
 #include <QCommandLineParser>
 #include <QDir>
+#include <QFileInfo>
+#include <QSettings>
 
 int main(int argc, char** argv)
 {
@@ -25,23 +27,38 @@ int main(int argc, char** argv)
 	app.setDesktopFileName("connectagram");
 #endif
 
-	QString path = app.applicationDirPath();
-	QStringList paths;
-	paths.append(path + "/data/");
-	paths.append(path + "/../share/connectagram/data/");
-	paths.append(path + "/../Resources/data/");
-	QDir::setSearchPaths("connectagram", paths);
+	// Find application data
+	const QString appdir = app.applicationDirPath();
+	const QString datadir = QDir::cleanPath(appdir + "/" + CONNECTAGRAM_DATADIR);
 
-	LocaleDialog::loadTranslator("connectagram_");
+	// Handle portability
+#ifdef Q_OS_MAC
+	const QFileInfo portable(appdir + "/../../../Data");
+#else
+	const QFileInfo portable(appdir + "/Data");
+#endif
+	if (portable.exists() && portable.isWritable()) {
+		QSettings::setDefaultFormat(QSettings::IniFormat);
+		QSettings::setPath(QSettings::IniFormat, QSettings::UserScope, portable.absoluteFilePath() + "/Settings");
+	}
 
-	ScoresDialog::migrate();
+	// Load application language
+	LocaleDialog::loadTranslator("connectagram_", datadir);
 
+	// Handle commandline
 	QCommandLineParser parser;
 	parser.setApplicationDescription(Window::tr("A word unscrambling game"));
 	parser.addHelpOption();
 	parser.addVersionOption();
 	parser.process(app);
 
+	// Find word lists
+	QDir::setSearchPaths("connectagram", { datadir + "/gamedata/" });
+
+	// Convert old scores to new format
+	ScoresDialog::migrate();
+
+	// Create main window
 	Window window;
 
 	return app.exec();
